@@ -110,9 +110,7 @@ impl <'a> MessageBox<'a> {
     pub fn show(&self,frame: Frame) -> gtk::ResponseType {
         use gtk::prelude::*;
         gtk::init().expect("Failed to initialize gtk.");
-        let window = gtk::Window::new(gtk::WindowType::Toplevel);
-
-        window.set_title(self.title);
+        let window = frame.get_window();
 
         let dialog = gtk::MessageDialog::new(
             Some(&window),
